author = 'Sergey Zharkov'
license_type = 'MIT'
email = 'sttv-pc@mail.ru'
version = '1.29.1'
repo_name = 'manga-py/manga-py'
repo_url = 'https://github.com/%s' % repo_name

__all__ = [
    'author',
    'license_type',
    'email',
    'version',
    'repo_name',
    'repo_url',
]
